﻿#NoTrayIcon
#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_Icon=Calendar.ico
#AutoIt3Wrapper_Outfile=Tagezaehler.exe
#AutoIt3Wrapper_Res_Description=Tagezaehler
#AutoIt3Wrapper_Res_Fileversion=1.0.0.0
#AutoIt3Wrapper_Res_LegalCopyright=Oscar (www.autoit.de)
#AutoIt3Wrapper_Res_Language=1031
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****
#include <Date.au3>
#include <EditConstants.au3>
#include <GUIConstantsEx.au3>
#include <StaticConstants.au3>
#include '_DateImage.au3'
Opt('GUIOnEventMode', 1)

Global $sInifile = @ScriptDir & '\Tagezaehler.ini'

Global $iLeft = Number(IniRead($sInifile, 'Config', 'Left', -1)) ; X-Position des Fensters aus der Inidatei lesen
Global $iTop = Number(IniRead($sInifile, 'Config', 'Top', -1)) ; Y-Position des Fensters aus der Inidatei lesen
Global $tPos = DllStructCreate($tagPOINT) ; Point-Structur erstellen für die Monitor-Abfrage
DllStructSetData($tPos, 'X', $iLeft) ; X-Position in die Structur eintragen
DllStructSetData($tPos, 'Y', $iTop) ; Y-Position in die Structur eintragen
Global $hMonitor = _WinAPI_MonitorFromPoint($tPos, 0) ; ermitteln auf welchen Monitor das Fenster angezeigt wird
If $hMonitor = 0 Then ; wenn außerhalb, dann...
	$iLeft = -1 ; X-Position auf den aktuellen Monitor mittig ausrichten
	$iTop = -1 ; Y-Position auf den aktuellen Monitor mittig ausrichten
EndIf

Global $sTargetDate = IniRead($sInifile, 'Config', 'Date', '2017/06/04 00:00:00')
Global $iYear = StringLeft($sTargetDate, 4)
Global $iSeconds = 0

Global $hGui = GUICreate('Urlaub ' & $iYear, 780, 320, $iLeft, $iTop)
GUISetIcon(@ScriptDir & '\Calendar.ico')
GUISetBkColor(0x000000)
GUISetOnEvent($GUI_EVENT_CLOSE, '_CloseGui')

GUICtrlCreatePic(@ScriptDir & '\urlaub.jpg', 0, 0, 780, 290)
GUICtrlSetState(-1, $GUI_DISABLE)

Global $idDateImage = _DateImage_Create(4, 246, $sTargetDate)
GUICtrlSetOnEvent(-1, '_ChangeDate')

GUICtrlCreateLabel('Der nächste Urlaub beginnt in:', 100, 260, 500, 24, $SS_CENTER)
GUICtrlSetFont(-1, 16, 400, 0, 'Times New Roman', 5)
GUICtrlSetColor(-1, 0xD0D0D0)
GUICtrlSetBkColor(-1, $GUI_BKCOLOR_TRANSPARENT)

Global $idDisplay = GUICtrlCreateLabel('', 90, 290, 680, 30, $SS_CENTER)
GUICtrlSetFont(-1, 18, 400, 0, 'Times New Roman', 5)
GUICtrlSetColor(-1, 0xD0D0D0)
GUICtrlSetBkColor(-1, $GUI_BKCOLOR_TRANSPARENT)

GUISetState()
_ShowTime()
AdlibRegister('_ShowTime', 1000)
WinWaitClose($hGui)
Exit

Func _ChangeDate()
	Local $sDate = _InputDateBox(1, '', '', $sTargetDate)
	If @error Then Return
	$sTargetDate = $sDate
	_DateImage_SetData($idDateImage, $sTargetDate)
	$iYear = StringLeft($sTargetDate, 4)
	WinSetTitle($hGui, '', 'Urlaub ' & $iYear)
	IniWrite($sInifile, 'Config', 'Date', $sTargetDate)
EndFunc

Func _ShowTime()
	$iSeconds = -(_DateDiff('s', $sTargetDate, _NowCalc()))
	GUICtrlSetData($idDisplay, _TicksToTimeFormat($iSeconds * 1000, '%ww %dd %hh %mm %ss'))
EndFunc

Func _CloseGui()
	Local $aWinPos = WinGetPos($hGui)
	If Not @error Then
		IniWrite($sInifile, 'Config', 'Left', $aWinPos[0])
		IniWrite($sInifile, 'Config', 'Top', $aWinPos[1])
	EndIf
	GUIDelete($hGui)
EndFunc

;===============================================================================
; Function Name:   _TicksToTimeFormat($iTicks, $sFormat = '%hh:%mm:%ss')
; Description::    Diese Funktion wandelt Millisekunden in ein anzugebenes Zeitformat um
; Parameter(s):    $iTicks = Zeit in Millisekunden
;                  $sFormat:
;                            %ww für Wochen
;                            %dd für Tage
;                            %hh für Stunden
;                            %mm für Minuten
;                            %ss für Sekunden
;                            %ms für Millisekunden
;                            sonstige Zeichen, die dazwischen stehen, werden übernommen
; Requirement(s):  -
; Return Value(s): Zeit im ausgewählten Format (String)
; Author(s):       Oscar (www.autoit.de)
;===============================================================================
Func _TicksToTimeFormat($iTicks, $sFormat = '%hh:%mm:%ss')
	Local $aTime[6], $sOut, $aTimeFormat[6] = ['ww', 'dd', 'hh', 'mm', 'ss', 'ms'], $aFormat
	Local $aTimeString[6][2] = [['Woche', 'n'], ['Tag', 'en'], ['Stunde', 'n'], ['Minute', 'n'], ['Sekunde', 'n'], ['Millisekunde', 'n']]
	$aTime[4] = Int($iTicks / 1000)
	$aTime[5] = $iTicks - $aTime[4] * 1000
	$aTime[0] = Int($aTime[4] / 604800)
	$aTime[4] = Mod($aTime[4], 604800)
	$aTime[1] = Int($aTime[4] / 86400)
	$aTime[4] = Mod($aTime[4], 86400)
	$aTime[2] = Int($aTime[4] / 3600)
	$aTime[4] = Mod($aTime[4], 3600)
	$aTime[3] = Int($aTime[4] / 60)
	$aTime[4] = Mod($aTime[4], 60)
	$aFormat = StringRegExp($sFormat, '%(.{2})', 3)
	If Not IsArray($aFormat) Then Return SetError(1, 0, $iTicks)
	For $i = 0 To UBound($aFormat) - 1
		For $j = 0 To UBound($aTimeFormat) - 1
			If StringLeft($aFormat[$i], 2) = $aTimeFormat[$j] Then
				$sOut &= StringFormat('%' & 2 + ($j = 5) & 'i', $aTime[$j]) & StringMid($aFormat[$i], 3) & ' '
				$sOut &= $aTimeString[$j][0] & ($aTime[$j] <> 1 ? $aTimeString[$j][1] : '')
				$sOut &= ($i = UBound($aTimeFormat) - 3 ? ' und ' : ', ')
			EndIf
		Next
	Next
	Return StringTrimRight($sOut, 2)
EndFunc   ;==>_TicksToTimeFormat

;===============================================================================
; Function Name:	_InputDateBox([$iFormat][, $sTitle][, $sText][, $sDefaultDate][, $hParent])
; Description:		Fragt den Benutzer nach Datum oder Datum und Uhrzeit und gibt dies als String zurück
; Parameter(s):		$iFormat = 0 oder 1
;					bei 0 wird nur nach dem Datum gefragt (Uhrzeit wird dann als "00:00:00" zurückgegeben)
;					bei 1 wird nach Datum und Uhrzeit gefragt
; Requirement:		-
; Return Value(s):	bei Erfolg = String in Form von: "YYYY/MM/DD hh:mm:ss"
;					bei Abbruch = Leerstring und @error = 1
; Author(s):		Oscar (www.autoit.de)
;===============================================================================
Func _InputDateBox($iFormat = 1, $sTitle = '', $sText = '', $sDefaultDate = '', $hParent = '')
	If $iFormat < 0 Or $iFormat > 1 Then $iFormat = 1
	If $sTitle = '' Or $sTitle = Default Then $sTitle = 'Datum-Box'
	If $sText = '' Or $sText = Default Then $sText = 'Bitte Datum auswählen!'
	If $iFormat Then $sText = 'Bitte Datum und Uhrzeit auswählen!'
	Local $iOnEventMode = Opt('GUIOnEventMode', 0), $sRetDate = '', $iError = 0
	Local $hGui = GUICreate($sTitle, 220 + $iFormat * 85, 130, Default, Default, Default, 8, $hParent)
	GUISetBkColor(0xCCCCCC, $hGui)
	GUISetIcon('shell32.dll', 24, $hGui)
	GUICtrlCreateGroup($sText, 10, 20, 200 + $iFormat * 85, 70)
	GUICtrlSetFont(-1, 10, 400, 0, 'Arial', 5)
	GUICtrlCreateIcon('shell32.dll', -21, 20, 48, 32, 32)
	Local $idDate = GUICtrlCreateDate($sDefaultDate, 65, 49, 135 + $iFormat * 85, 30)
	Local $hWnd = GUICtrlGetHandle($idDate)
	GUICtrlSetFont(-1, 14, 400, 0, 'Verdana', 5)
	If $iFormat Then
		Local $DTM_SETFORMAT_ = 0x1032
		Local $sFormat = 'dd.MM.yyyy  HH:mm:ss'
		GUICtrlSendMsg($idDate, $DTM_SETFORMAT_, 0, $sFormat)
	Else
		GUICtrlSetStyle($idDate, 0)
	EndIf
	GUICtrlCreateGroup('', -99, -99, 1, 1)
	Local $idOk = GUICtrlCreateButton('Ok', 60 + $iFormat * 85, 100, 60, 25, 1) ; <- Value 1 = $BS_DEFPUSHBUTTON
	Local $idCancel = GUICtrlCreateButton('Abbrechen', 130 + $iFormat * 85, 100, 80, 25)
	GUISetState(@SW_SHOW, $hGui)
	While True
		Switch GUIGetMsg()
			Case $idCancel, -3 ; <- Value -3 = $GUI_EVENT_CLOSE
				$iError = 1
				ExitLoop
			Case $idOk
				$sRetDate = StringRegExpReplace(GUICtrlRead($idDate), '(\d{2})\.(\d{2})\.(\d{4}).*', '$3/$2/$1')
				If $iFormat Then
					$sRetDate &= StringRegExpReplace(GUICtrlRead($idDate), '\d{2}\.\d{2}\.\d{4}  (\d{2}):(\d{2}):(\d{2})', ' $1:$2:$3')
				Else
					$sRetDate &= ' 00:00:00'
				EndIf
				ExitLoop
		EndSwitch
	WEnd
	GUIDelete($hGui)
	Opt('GUIOnEventMode', $iOnEventMode)
	Return SetError($iError, 0, $sRetDate)
EndFunc   ;==>_InputDateBox
